@@ -1,19 +1,29 @@
-"""Tests to verify the API functionality of OE Python Template."""
+"""Tests to verify the API functionality of OE Python Template Example."""
 
 from unittest.mock import patch
 
 import pytest
 from fastapi.testclient import TestClient
 
-from oe_python_template_example.api import app
+from oe_python_template_example.api import api
 
-ECHO_PATH = "/echo"
+HELLO_WORLD_PATH_V1 = "/api/v1/hello-world"
+HELLO_WORLD_PATH_V2 = "/api/v2/hello-world"
+
+ECHO_PATH_V1 = "/api/v1/echo"
+ECHO_PATH_V2 = "/api/v2/echo"
+
+HEALTH_PATH_V1 = "/api/v1/health"
+HEALTH_PATH_V2 = "/api/v2/health"
+
+HEALTHZ_PATH_V1 = "/api/v1/healthz"
+HEALTHZ_PATH_V2 = "/api/v2/healthz"
 
 
 @pytest.fixture
 def client() -> TestClient:
     """Provide a FastAPI test client fixture."""
-    return TestClient(app)
+    return TestClient(api)
 
 
 def test_root_endpoint_returns_404(client: TestClient) -> None:
@@ -25,7 +35,11 @@ def test_root_endpoint_returns_404(client: TestClient) -> None:
 
 def test_hello_world_endpoint(client: TestClient) -> None:
     """Test that the hello-world endpoint returns the expected message."""
-    response = client.get("/hello-world")
+    response = client.get(HELLO_WORLD_PATH_V1)
+    assert response.status_code == 200
+    assert response.json()["message"].startswith("Hello, world!")
+
+    response = client.get(HELLO_WORLD_PATH_V2)
     assert response.status_code == 200
     assert response.json()["message"].startswith("Hello, world!")
 
@@ -33,34 +47,52 @@ def test_hello_world_endpoint(client: TestClient) -> None:
 def test_echo_endpoint_valid_input(client: TestClient) -> None:
     """Test that the echo endpoint returns the input text."""
     test_text = "Test message"
-    response = client.post(ECHO_PATH, json={"text": test_text})
+
+    response = client.post(ECHO_PATH_V1, json={"text": test_text})
+    assert response.status_code == 200
+    assert response.json() == {"message": test_text}
+
+    response = client.post(ECHO_PATH_V2, json={"utterance": test_text})
     assert response.status_code == 200
     assert response.json() == {"message": test_text}
 
 
 def test_echo_endpoint_empty_text(client: TestClient) -> None:
     """Test that the echo endpoint validates empty text."""
-    response = client.post(ECHO_PATH, json={"text": ""})
+    response = client.post(ECHO_PATH_V1, json={"text": ""})
+    assert response.status_code == 422  # Validation error
+
+    response = client.post(ECHO_PATH_V2, json={"utterance": ""})
     assert response.status_code == 422  # Validation error
 
 
 def test_echo_endpoint_missing_text(client: TestClient) -> None:
     """Test that the echo endpoint validates missing text field."""
-    response = client.post(ECHO_PATH, json={})
+    response = client.post(ECHO_PATH_V1, json={})
+    assert response.status_code == 422  # Validation error
+
+    response = client.post(ECHO_PATH_V2, json={})
     assert response.status_code == 422  # Validation error
 
 
 def test_health_endpoint(client: TestClient) -> None:
     """Test that the health endpoint returns UP status."""
-    response = client.get("/health")
+    response = client.get(HEALTH_PATH_V1)
     assert response.status_code == 200
     assert response.json()["status"] == "UP"
     assert response.json()["reason"] is None
 
+    response = client.get(HEALTH_PATH_V2)
+    assert response.status_code == 200
+    assert response.json()["status"] == "UP"
+    assert response.json()["reason"] is None
 
-def test_healthz_endpoint(client: TestClient) -> None:
-    """Test that the healthz endpoint returns UP status."""
-    response = client.get("/healthz")
+    response = client.get(HEALTHZ_PATH_V1)
+    assert response.status_code == 200
+    assert response.json()["status"] == "UP"
+    assert response.json()["reason"] is None
+
+    response = client.get(HEALTHZ_PATH_V2)
     assert response.status_code == 200
     assert response.json()["status"] == "UP"
     assert response.json()["reason"] is None
@@ -73,20 +105,22 @@ def test_health_endpoint_down(mock_service, client: TestClient) -> None:
     mock_service_instance = mock_service.return_value
     mock_service_instance.healthy.return_value = False
 
-    response = client.get("/health")
+    response = client.get(HEALTH_PATH_V1)
     assert response.status_code == 500
     assert response.json()["status"] == "DOWN"
     assert response.json()["reason"] == "Service is unhealthy"
 
+    response = client.get(HEALTH_PATH_V2)
+    assert response.status_code == 500
+    assert response.json()["status"] == "DOWN"
+    assert response.json()["reason"] == "Service is unhealthy"
 
-@patch("oe_python_template_example.api.Service")
-def test_healthz_endpoint_down(mock_service, client: TestClient) -> None:
-    """Test that the healthz endpoint returns 500 status when service is unhealthy."""
-    # Configure the mock to return unhealthy status
-    mock_service_instance = mock_service.return_value
-    mock_service_instance.healthy.return_value = False
+    response = client.get(HEALTHZ_PATH_V1)
+    assert response.status_code == 500
+    assert response.json()["status"] == "DOWN"
+    assert response.json()["reason"] == "Service is unhealthy"
 
-    response = client.get("/healthz")
+    response = client.get(HEALTHZ_PATH_V2)
     assert response.status_code == 500
     assert response.json()["status"] == "DOWN"
     assert response.json()["reason"] == "Service is unhealthy"
